import * as React from 'react';
import { IgrStrategyBasedIndicator, IIgrStrategyBasedIndicatorProps } from "./igr-strategy-based-indicator";
import { DetrendedPriceOscillatorIndicator } from "./DetrendedPriceOscillatorIndicator";
/**
 * Represents a IgxDataChartComponent Detrended Price Oscillator indicator series.
 * Default required members: Close
*
* The `DetrendedPriceOscillatorIndicator` class represents a IgxDataChartComponent Detrended Price Oscillator indicator series.
*
* ```ts
* <IgrDataChart
*     dataSource={this.state.dataSource}
*     width="700px"
*     height="500px">
*
*     <IgrCategoryXAxis name="xAxis" label="Year" />
*     <IgrNumericYAxis  name="yAxis" />
*
*     <IgrDetrendedPriceOscillatorIndicator
*         name="series1"
*         xAxisName="xAxis"
*         yAxisName="yAxis"
* 		openMemberPath="Open"
* 		highMemberPath="High"
*         lowMemberPath="Low"
* 		period= {30} />
*  </IgrDataChart>
* ```
*/
export declare class IgrDetrendedPriceOscillatorIndicator extends IgrStrategyBasedIndicator<IIgrDetrendedPriceOscillatorIndicatorProps & React.HTMLAttributes<HTMLElement>> {
    protected createImplementation(): DetrendedPriceOscillatorIndicator;
    /**
                                 * @hidden
                                 */
    get i(): DetrendedPriceOscillatorIndicator;
    constructor(props: IIgrDetrendedPriceOscillatorIndicatorProps & React.HTMLAttributes<HTMLElement>);
    /**
     * Gets or sets the moving average period for the current DetrendedPriceOscillatorIndicator object.
     * The typical, and initial, value for DPO periods is 20.
    *
    * You can use the `period` to set the current moving average period.
    *
    * ```ts
    * <IgrDataChart
    *     dataSource={this.state.dataSource}
    *     width="700px"
    *     height="500px">
    *
    *     <IgrCategoryXAxis name="xAxis" label="Year" />
    *     <IgrNumericYAxis  name="yAxis" />
    *
    *     <IgrDetrendedPriceOscillatorIndicator
    *         name="series1"
    *         xAxisName="xAxis"
    *         yAxisName="yAxis"
    * 		openMemberPath="Open"
    *         highMemberPath="High"
    *         lowMemberPath="Low"
    * 		period=30 />
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * this.series.period = 30;
    * ```
    */
    get period(): number;
    set period(v: number);
}
export interface IIgrDetrendedPriceOscillatorIndicatorProps extends IIgrStrategyBasedIndicatorProps {
    /**
     * Gets or sets the moving average period for the current DetrendedPriceOscillatorIndicator object.
     * The typical, and initial, value for DPO periods is 20.
    *
    * You can use the `period` to set the current moving average period.
    *
    * ```ts
    * <IgrDataChart
    *     dataSource={this.state.dataSource}
    *     width="700px"
    *     height="500px">
    *
    *     <IgrCategoryXAxis name="xAxis" label="Year" />
    *     <IgrNumericYAxis  name="yAxis" />
    *
    *     <IgrDetrendedPriceOscillatorIndicator
    *         name="series1"
    *         xAxisName="xAxis"
    *         yAxisName="yAxis"
    * 		openMemberPath="Open"
    *         highMemberPath="High"
    *         lowMemberPath="Low"
    * 		period=30 />
    *  </IgrDataChart>
    * ```
    *
    * ```ts
    * this.series.period = 30;
    * ```
    */
    period?: number | string;
}
